#! /usr/bin/env sh

set \
"pip" \
"setuptools" \
"wheel" \
\
"uv" \
\
"pelican" \
\
"hatch" \
\
"Sphinx" \
"sphinx-rtd-theme" \
\
"gitlint" \
\
"pydoclint" \
"pylint" \
"ruff" \
\
"pytest" \
\
"toml" \
\
"twine" \
\
"mypy" \
"pyright" \
\
"ruamel.yaml" \
"PyYAML" \
"types-PyYAML" \

file="$(readlink --canonicalize-existing "${0}")"
root="$(dirname "${file}")"
root="${root}/root/py/pi"
tmp="${root}/tmp"

rm --force --recursive \
~/.cache/pip "${root}"

python3 -m pip \
download \
--dest "${root}" \
"${@}"

prefix="Name: "
for wheel in "${root}/"*; do
    echo
    echo "${wheel}"
    file="$(basename "${wheel}")"
    case "${file}" in
    *.tar.gz)
        short="${file%.*}"
        short="${short%.*}"
        ;;
    *.whl)
        short="${file%.*}"
        ;;
    esac
    file_name="$(echo "${short}" | cut -d "-" -f 1)"
    file_version="$(echo "${short}" | cut -d "-" -f 2)"
    case "${file}" in
    *.tar.gz)
        meta_data="${file_name}-${file_version}/${file_name}.egg-info/PKG-INFO"
        tar xf "${wheel}" -C "${tmp}" "${meta_data}"
        ;;
    *.whl)
        meta_data="${file_name}-${file_version}.dist-info/METADATA"
        unzip "${wheel}" "${meta_data}" -d "${tmp}"
        ;;
    esac
    name="$(grep "${prefix}" "${tmp}/${meta_data}" | sed "s|${prefix}||")"
    echo "${name}"
    name="$(echo "${name}" | tr "[:upper:]" "[:lower:]")"
    name="$(echo "${name}" | tr "." "-")"
    name="$(echo "${name}" | tr "_" "-")"
    name="$(echo "${name}" | tr -d "\r")"
    echo "${name}"
    sub="${root}/simple/${name}"
    mkdir --parents "${sub}"
    mv -i "${root}/${file_name}-"* "${sub}/"
done

rm --force --recursive "${tmp}"
